
from .convert_score_and_distance_functions import convert_distance_function_to_score_function
from .convert_score_and_distance_functions import create_weighted_similarity_function

from .Word import Word
from .Sentence import Sentence
from .get_char_by_char_equality import get_char_by_char_equality

from .get_similarity import get_similarities, get_similarity
from .get_sentence_similarity import get_sentence_distance
from .get_string_similarity import get_string_similarity

from .find_most_similar import find_most_similar

